<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "https://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="https://www.w3.org/1999/xhtml">

<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta name="viewport" content="width=device-width" />

    <!-- Visit https://get.foundation/emails/docs/css-guide.html#boilerplate -->
    <!-- <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/foundation-emails/2.3.1/foundation-emails.min.css"> -->

    <!-- Your CSS to inline should be added here  -->
    <style>
        body {
            background: #fafafa;
            color: #4a4a4a;
        }
    </style>

    {% block head %}{% endblock %}
</head>

<body>
    <table class="body" data-made-with-foundation>
        <tr>
            <td class="float-center" align="center" valign="top">
                <center>
                    {% block body %}{% endblock %}
                </center>
            </td>
        </tr>
    </table>
</body>

</html>
